MethodChannelBiometricCrypto class
- Inheritance
-
- Object
- PlatformInterface
- BiometricCryptoPlatform
- MethodChannelBiometricCrypto
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
authenticate(
) → Future< bool> -
override
-
deleteKey(
String alias) → Future< void> -
override
-
generateKey(
String alias) → Future< void> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
getPublicKey(
String alias) → Future< String> -
override
-
isBiometricAvailable(
) → Future< bool> -
override
-
keyExists(
String alias) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
String alias, String challenge) → Future< String> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited