BiometricCryptoPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BiometricCryptoPlatform
Implementers

Constructors

BiometricCryptoPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate() Future<bool>
deleteKey(String alias) Future<void>
generateKey(String alias) Future<void>
getPlatformVersion() Future<String?>
getPublicKey(String alias) Future<String>
isBiometricAvailable() Future<bool>
keyExists(String alias) Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(String alias, String challenge) Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BiometricCryptoPlatform
getter/setter pair